function a() {}
function b() {}
function foo({ a: b__2  }) {
    expect(b__2).toBe('a');
}
foo({
    a: 'a'
});
